pub(crate) fn supervisor(command: &str) -> SupervisorExpand description
The service manager, or a refusal naming what this machine is.
pub(crate) fn supervisor(command: &str) -> SupervisorThe service manager, or a refusal naming what this machine is.