ExecutionContext

Struct ExecutionContext 

pub struct ExecutionContext<'a> { /* private fields */ }
Context of a task execution body.

Implementations

Source

impl<'a> ExecutionContext<'a>

pub fn self_task(&self) -> RunningTask

Get the running task handle of the current task.

pub fn choir(&self) -> &'a Arc<Choir>

Return the main choir.

pub fn fork<N: Into<Name>>(&self, name: N) -> ProtoTask<'_>

Fork the current task.

The new task will block all the same dependents as the currently executing task.

This is useful because it allows creating tasks on the fly from within other tasks. Generally, making a task in flight depend on anything is impossible. But one can fork a dependency instead.

pub fn add_fork<D: AsRef<Notifier>>(&self, other: &D)

Register an existing task as a fork.

It will block all the dependents of the currently executing task.

Will panic if the other task is already a fork of something.