pub struct RunningTask { /* private fields */ }Expand description
Task that is already scheduled for running.
Implementations
Sourceimpl RunningTask
impl RunningTask
Sourcepub fn join(&self) -> MaybePanic
pub fn join(&self) -> MaybePanic
Block until the task has finished executing.
Sourcepub fn join_active(&self) -> MaybePanic
pub fn join_active(&self) -> MaybePanic
Block until the task has finished executing. Also, use the current thread to help in the meantime.
Sourcepub fn join_debug(&self, timeout: Duration) -> MaybePanic
pub fn join_debug(&self, timeout: Duration) -> MaybePanic
Block until the task has finished executing, with timeout. Panics and prints helpful info if the timeout is reached.